summaryrefslogtreecommitdiff
path: root/protocols/Yahoo/main.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'protocols/Yahoo/main.cpp')
-rw-r--r--protocols/Yahoo/main.cpp9
1 files changed, 2 insertions, 7 deletions
diff --git a/protocols/Yahoo/main.cpp b/protocols/Yahoo/main.cpp
index 74f5285461..bb66cf0206 100644
--- a/protocols/Yahoo/main.cpp
+++ b/protocols/Yahoo/main.cpp
@@ -146,12 +146,7 @@ extern "C" __declspec(dllexport) PLUGININFOEX* MirandaPluginInfoEx(DWORD miranda
}
/*
* MirandaPluginInterfaces - Notifies the core of interfaces implemented
* Parameters: none
*/
-static const MUUID interfaces[] = {MIID_PROTOCOL, MIID_LAST};
-
-extern "C" __declspec(dllexport) const MUUID* MirandaPluginInterfaces(void)
-{
- return interfaces;
-}
+extern "C" __declspec(dllexport) const MUUID MirandaInterfaces[] = {MIID_PROTOCOL, MIID_LAST};
@@ -146,12 +146,7 @@ extern "C" __declspec(dllexport) PLUGININFOEX* MirandaPluginInfoEx(DWORD miranda
}
/*
- * MirandaPluginInterfaces - Notifies the core of interfaces implemented
+ * MirandaInterfaces - Notifies the core of interfaces implemented
* Parameters: none
*/